<?php
/**
 *
 *
 * @package plugins
 * @subpackage abook_imapfolder
 * @author Samuel Graenacher <xplo@users.sourceforge.net>
 * @copyright Copyright &copy; 2005, Fr. Sauter AG
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 */
 
class EntryReader {
    var $rawLines; // Array of strings, one str per line
    
    var $parsed = false;
    
    var $parsedData;
    
    var $errors;
    
    var $prefixes;
    var $prefixDelimiter = ':';
    
    // perl regexps that match when line is a comment.
    // note that multiline comments are not (yet?) supported
    var $commentRegexps = Array('/^\s*\#/', '/^\s*\;/','#^\s*\/\/#');
    
    // perl regexps for the entry start/stop markers
    var $entryStartReg = '/^ENTRY/';
    var $entryStopReg  = '/^EOENTRY/';
    
    // NOTE FOR USERS OF THIS CLASS:
    // All of the above regexps can be externally overridden, but this should
    // be done only after the Constructor has been called but before any other
    // method has been invoked!
    
    function EntryReader() {
        // Constructor... does nothing for now..
        $this->prefixes = Array();
    }
    
    function doParse() {
        if (!is_array($this->rawLines)) {
            $this->errors[] = "Cannot parse before reading!";
            return false;
        }
        
        $pd = Array(); // This array will become parsedData eventually.
        
        $inEntry = false;
        $tempEntry = Array();
        
        $linecount = count($this->rawLines);
        for ($i = 0; $i<$linecount; $i++) {
            // Check if line is a useless comment..
            $isComment = false;
            while (list($dummy,$pattern)=each($this->commentRegexps)) {
                if (preg_match($pattern, $this->rawLines[$i][0])) {
                    $isComment = true;
                    break;
                }
            }
            if ($isComment == true) {
                continue; // Line seems to be a comment, skipping...
            }
            
            // Handle START signal
            if (preg_match($this->entryStartReg,$this->rawLines[$i])) {
                // An entry is starting.. but isn't one already open?
                if ($inEntry == true) {
                    // an entry is already open, must be a corrupt one, discard
                    // the other one completely!
                    $tempEntry = Array();
                }
                $inEntry = true;
            }
            
            unset($regs);
            // Handle fields that look usable
            if (preg_match('/(\w+)\:\s*(.*)/i',$this->rawLines[$i],$regs) 
                && $inEntry) {
                $key = trim($regs[1]);
                $value = trim($regs[2]);
                $lkey = strtolower($key);
                if ((isset($this->prefixes["$lkey"])) &&
                    (is_string($this->prefixes["$lkey"])) &&
                    (strlen($this->prefixes["$lkey"]) >
                       strlen($this->prefixDelimiter)
                     )
                    ) { 
                    $prefix = $this->prefixes["$lkey"];
                } else {
                    $prefix = '';
                }
                $tempEntry["$lkey"][] = $prefix.$value;
            }
            
            // Handle STOP signal
            if (preg_match($this->entryStopReg,$this->rawLines[$i])) {
                if (!$inEntry) {
                    // Uhh..
                    continue;
                }
                // Finishing the entry and appending it to $pd
                $pd[] = $tempEntry;
                $tempEntry = Array();
                $inEntry = false;
            }
        }
        
        if (count($pd) > 0) {
            $this->parsedData = $pd;
            unset($pd);
            $this->parsed = true;
        }
        
    }
    
    function readFromString($inputstr) {
        $this->rawLines = split("\n", $inputstr);
        $this->doParse();
    }
    
    function setPrefix($attrib, $prefix) {
        $lattrib = strtolower($attrib);
        $this->prefixes["$lattrib"] = $prefix.$this->prefixDelimiter;
    }
    
    function setPrefixDelimiter($deli) {
        $this->prefixDelimiter = $deli;
    }
}
?>
<?php /* 
jEdit local settings 
:indentSize=4:noTabs=true:maxLineLen=80:wrap=hard:mode=php:deepIndent=true:
*/ ?>
