<?php
/**
 *
 *
 * @package plugins
 * @subpackage abook_imapfolder
 * @author Samuel Graenacher <xplo@users.sourceforge.net>
 * @copyright Copyright &copy; 2005, Fr. Sauter AG
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 */


class EntryWriter {
    var $rawString;
    
    var $written = false;
    
    var $parsedData;
    
    var $errors;
    
    var $prefixDelimiter = ':';
    
    // perl regexps that match when line is a comment.
    // note that multiline comments are not (yet?) supported
    var $commentRegexps = Array('/^\s*\#/', '/^\s*\;/','#^\s*\/\/#');
    
    // perl regexps for the entry start/stop markers
    var $entryStartReg = '/^ENTRY/';
    var $entryStopReg  = '/^EOENTRY/';
    
    // NOTE FOR USERS OF THIS CLASS:
    // All of the above regexps can be externally overridden, but this should
    // be done only after the Constructor has been called but before any other
    // method has been invoked!
    
    function EntryWriter() {
        $this->prefixes = Array();
    }

    function setPrefixDelimiter($deli) {
        $this->prefixDelimiter = $deli;
    }
    
    function stripPrefix($inval) {
        $subval = $inval;
        if (strstr($subval, $this->prefixDelimiter)) {
            $popval = array_pop(split($this->prefixDelimiter,$subval));
        } else {
            $popval = $subval;
        }
        return $popval;
    }
    
    
    function writeSingleEntry($struct, $stripPrefixes = true, 
                              $addTimestamp = true) {
        $this->rawString = "ENTRY\n";
        
        // FIXME: Add serialized cache (incl. timestamp!) here.
        
        //
        if ($addTimestamp) {
            $this->rawString .= 'modified: '.time()."\n";
            // This modified attribute tells the last time the unserialized
            // Entry was modified.
        }
        
        // Add the creator
        global $username;
        if (isset($username)&&is_string($username)&&!empty($username)) {
            $this->rawString .= 'editedby: '.$username."\n";
        }
        
        reset($struct);
        while(list($attribname,$attribvals) = each($struct)) {
            if (!is_array($attribvals)) {
                $this->errors .= "Input for writesingleEntry in wrong format\n";
                return false;
            }
            if (($addTimestamp)&&(strtolower($attribname) == 'modified')) {
                continue; // Skip using the attributes modifier, we write our
                          // own or none.
            }
            reset($attribvals);
            while (list($validx,$subval) = each($attribvals)) {
                if ($stripPrefixes) {
                    // Stripping prefixes requested..
                    $subval = $this->stripPrefix($subval);
                }
                $this->rawString .= $attribname.': '.$subval."\n";
            }
        }
        
        $this->rawString .= "EOENTRY\n";
        return $this->rawString;
    }
}


?>
<?php /* 
jEdit local settings 
:indentSize=4:noTabs=true:maxLineLen=80:wrap=hard:mode=php:deepIndent=true:
*/ ?>
