<?php
/**
 * Plugin to provide an IMAP based addressbook backend.
 *
 * Copyright (c) 2005 Fr. Sauter AG
 *
 * @package plugins
 * @subpackage abook_imapfolder
 * @author Samuel Graenacher <xplo@users.sourceforge.net>
 * @copyright Copyright &copy; 2005, Fr. Sauter AG
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License v2
 */


if (!defined("SM_PATH"))
    define('SM_PATH','../../');

define('ABOOK_IMAPFOLDER_VERSION', '1.53');

//include_once(SM_PATH . 'functions/i18n.php');
include_once(SM_PATH . 'functions/global.php');
include_once('var_export.php');
// Plugins configuration

$ait_dbg = '';

function testerCheck($cai) {
    global $username;
    global $ait_debug;
    
    if (!$username||empty($username)) {
        // No username yet..
        $ait_debug .= "tC: No username yet.\n";
        return true;
    }
    
    if (isset($cai['testers'])&&is_array($cai['testers'])&&
        (count($cai['testers']) > 0)
        ) {
        
        //print 'tC: Tester mode active.';
        $ait_debug .= 'tC: Tester mode active.'."\n";
        // Admin has set a list of testers.. checking if we're called by one..
        if (!in_array($username, $cai['testers'])) {
            //print "tC: $username is NOT a tester.\n";
            $ait_debug .= "tC: $username is NOT a tester.\n";
            return false; // Not a tester, exiting before installing the hooks.
        }
        //print "tC: $username IS a tester.\n";
        $ait_debug .= "tC: $username IS a tester.\n";
    }
    return true;
}

function squirrelmail_plugin_init_abook_imapfolder() {
    global $squirrelmail_plugin_hooks;
    global $username; // Needed for testers check
    global $cai;
    global $ait_debug;
    if (file_exists(SM_PATH . 'plugins/abook_imapfolder/config.php')) {
        include(SM_PATH . 'plugins/abook_imapfolder/config.php');
    } else {
        include(SM_PATH . 'plugins/abook_imapfolder/config.php.sample');
    }
    
    
    if (!testerCheck($cai)) {
        return;
    }

    $ait_debug .= "setup: Past testercheck.\n";
    
    $squirrelmail_plugin_hooks['abook_init']['abook_imapfolder'] = 
        'abook_imapfolder_abook_init';
    $squirrelmail_plugin_hooks['abook_add_class']['abook_imapfolder'] = 
        'abook_imapfolder_abook_add_class';
    $squirrelmail_plugin_hooks['addressbook_bottom']['abook_imapfolder'] = 
        'abook_imapfolder_addressbook_bottom';
}


/**
 * This hook function recieves the addressbook object while it is being loaded
 * and adds the abook_imap class into it (if it is enabled).
 * It can optionally also set the imap backend as the master ("localbackend")
 */
function abook_imapfolder_abook_init(&$args) {
    global $ait_dbg;
    global $cai;
    // Plugins configuration
    if (file_exists(SM_PATH . 'plugins/abook_imapfolder/config.php')) {
        include(SM_PATH . 'plugins/abook_imapfolder/config.php');
    } else {
        include(SM_PATH . 'plugins/abook_imapfolder/config.php.sample');
    }
    
    if (!testerCheck($cai)) {
        return;
    }
    
    $ait_dbg .= 'aih: Got the args object: '.var_export($args,1)."\n";
    
    $abook = &$args[1];
    
    // This loads the imap addressbook backend.
    if ($cfg_abook_imapfolder_enabled) {
        // Load as normal backend.
        $r = $abook->add_backend('imapfolder');
        if (!$r) {
            // Error output is disabled, as we don't know wether to show em.
            /*
            if ($showerr) {
                echo _('Error initializing imap addressbook.');
                echo _('Error: '.$abook->error);
            }
            */
            exit;
        }
        if ($cfg_abook_imapfolder_as_master) {
            // Load as master
            $abook->localbackend = $me = $abook->numbackends;
            $abook->localbackendname = $abook->backends[$me]->sname;
            unset($me);
        }
    } else {
        // Don't load at all..
    }
    
    $ait_dbg .= 'aih: Leaving the args object: '.var_export($args,1)."\n";
}

/**
 * This hook function simply includes the necessary files containing the class.
 */
function abook_imapfolder_abook_add_class($args) {
    // This one will load the class in final release.
    global $ait_dbg;
    global $cai;
    //global $cfg_abook_imapfolder_enabled;
    // Plugins configuration
    if (file_exists(SM_PATH . 'plugins/abook_imapfolder/config.php')) {
        include(SM_PATH . 'plugins/abook_imapfolder/config.php');
    } else {
        include(SM_PATH . 'plugins/abook_imapfolder/config.php.sample');
    }
    
    if (!testerCheck($cai)) {
        return;
    }
    
    /* Only load imap backend if the admin requested it in config */
    if (isset($cfg_abook_imapfolder_enabled) && $cfg_abook_imapfolder_enabled == true) {
        include_once('abook_imapfolder.php');
    }
    
    $ait_dbg .= 'aach: was called.'."\n";
    $ait_dbg .= "aach: enabled is ".var_export($cfg_abook_imapfolder_enabled,1).
                "\n";
}

/**
 * This hook function is only used for debugging and testing output.
 */
function abook_imapfolder_addressbook_bottom() {
    global $imapConnection;
    global $ait_dbg;
    global $abook_imapfolder_debug;
    $abook_imapfolder_debug = ' ';

    if (!defined("SM_PATH"))
        define('SM_PATH','../../');
    global $cai;
    if (file_exists(SM_PATH . 'plugins/abook_imapfolder/config.php')) {
        include(SM_PATH . 'plugins/abook_imapfolder/config.php');
    } else {
        include(SM_PATH . 'plugins/abook_imapfolder/config.php.sample');
    }
    
    if (isset($cai['don']) && ($cai['don'] == true)) {
        
        print "<br />\n";
        
        print "### abook_imapfolder bottom hook contents follows:<p />\n";
        
        print "<pre>".$ait_dbg."</pre><br /> \n";
        print "<pre>".$abook_imapfolder_debug."</pre><br /> \n";
        
        print "<p />### end of abook_imapfolder bottom hook contents.<p />\n";
        
    }

}

function abook_imapfolder_version() {
    // Could read this directly from the version file.
    // But there's too much overhead in opening and reading anoter file
    // each time we're called.
    return ABOOK_IMAPFOLDER_VERSION;
};

?>
<?php /* 
jEdit local settings 
:indentSize=4:noTabs=true:maxLineLen=80:wrap=hard:mode=php:
*/ ?>
